@@ -1,6 +1,6 @@
 =begin
 /****************************************************************************
-** $Id: qt/examples/action/main.cpp   2.2.2   edited 2000-08-31 $
+** $Id: application.rb,v 1.1.1.1 2002/12/22 14:19:45 taka-hr Exp $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -11,14 +11,16 @@
 =end
 #include <qapplication.h>
 #include "application.h"
-require "qt2"
-include Qt2
+require "qte"
+include Qte
+require "qpe"
+include Qpe
 require "application_lib.rb"
 
-    a = QApplication.new( [$0]+ARGV )
+    a = QPEApplication.new( [$0]+ARGV )
     mw = ApplicationWindow.new()
     mw.setCaption( "Document 1" )
-    mw.show()
-    Qt2::connect( a, QSIGNAL("lastWindowClosed()"), a, QSLOT("quit()") )
+    a.showMainWidget(mw)
+    Qte::connect( a, QSIGNAL("lastWindowClosed()"), a, QSLOT("quit()") )
     a.exec()
 
