@@ -1,7 +1,9 @@
 #!/usr/bin/env ruby
 
-require "qt"
-include Qt
+require "qte"
+include Qte
+require "qpe"
+include Qpe
 
 class MyWidget < QWidget
 def initialize
@@ -32,9 +34,8 @@ end
 
 end
 
-a = QApplication.new([$0]+ARGV)
+a = QPEApplication.new([$0]+ARGV)
 w = MyWidget.new
-a.setMainWidget(w)
-w.show
+a.showMainWidget(w)
 a.exec
 
