@@ -1,7 +1,7 @@
 #!/usr/bin/env ruby
 =begin
 /****************************************************************************
-** $Id: rubyedit2.rb,v 1.1.1.2 2000/11/14 17:05:08 horie Exp $
+** $Id: rubyedit2.rb,v 1.1.1.1 2002/12/22 14:19:55 taka-hr Exp $
 **
 ** Copyright (C) 1992-1998 Troll Tech AS.  All rights reserved.
 **
@@ -14,13 +14,15 @@
 #Where tool bar pixmaps are
 $PIXDIR = ".//"
 
-require "qt2"
-include Qt2
+require "qte"
+include Qte
+require "qpe"
+include Qpe
 
 require "rubyedit2_lib.rb"
 
 
-    a = QApplication.new([$0] + ARGV)
+    a = QPEApplication.new([$0] + ARGV)
     linNum = 0
     for i in 0..(ARGV.size - 1)
        if ARGV[i][0].chr == "-"
@@ -32,11 +34,10 @@ require "rubyedit2_lib.rb"
        end
     end
     mw = REditorWindow.new
-    a.setMainWidget(mw)
     mw.setCaption( "Document 1" )
     mw.resize(400,300)
-    mw.show
-    Qt2::connect( a, QSIGNAL("lastWindowClosed()"), a, QSLOT("quit()") )
+    a.showMainWidget(mw)
+    Qte::connect( a, QSIGNAL("lastWindowClosed()"), a, QSLOT("quit()") )
     if(!fname.nil?)
       mw.loadFile (fname)
     end
