@@ -2,29 +2,26 @@
 
 require 'fileutils'
 
-PACKAGE='ruby-qte'
-ARCH='arm'
-
 DESTDIR='/opt/QtPalmtop'
+WORKDIR='temp'
 
 def mk_control(version)
-  @control = Hash.new
-  File::open('control', 'w') do | outf |
+  FileUtils::mkdir_p(File::join(WORKDIR, 'CONTROL'))
+  control = Hash.new
+  File::open(File::join(WORKDIR, 'CONTROL/control'), 'w') do | outf |
     File::open('control.in') do | inf |
       inf.each do | l |
 	l.chomp!
 	l.gsub!(/%%VERSION%%/, version)
 	s = l.split(/: /)
-	@control[s[0]] = s[1]
+	control[s[0]] = s[1]
 	outf.print "#{l}\n"
       end
     end
   end
 
-  system("tar cvzf control.tar.gz ./control")
-  
-  return @control['Package'] + '_' + @control['Version'] + '_' + 
-    @control['Architecture'] + '.ipk'
+  return control['Package'] + '_' + control['Version'] + '_' + 
+    control['Architecture'] + '.ipk'
 end
 
 def mk_data
@@ -35,7 +32,7 @@ def mk_data
 	src.gsub!(%r|/./|, '/')
 	
 	m = /#{DESTDIR}/.match(src)
-	dest = '.' + m[0] + m.post_match
+	dest = File::join(WORKDIR, m[0] + m.post_match)
 	
 	dir = %r|^.*/|.match(dest)[0]
 	
@@ -46,12 +43,13 @@ def mk_data
       end
     end
   end
+end
 
-  system("tar cvzf data.tar.gz .#{DESTDIR}")
+if File::directory?(WORKDIR)
+  FileUtils::rm_r(WORKDIR)
 end
 
 mk_data
 ipkname = mk_control(ARGV[0])
 
-system("tar cvzf #{ipkname} ./control.tar.gz ./data.tar.gz ./debian-binary")
-
+system('ipkg-build', WORKDIR)
